import { createHostModule } from '@wix/sdk-runtime/host-modules';
const getFromHostErrorHandlerOrDefault = (fn) => (host) => {
    if (!host.getErrorHandler) {
        throw new Error('Error handler is not available. Make sure to include the error handler in the host.');
    }
    return fn(host.getErrorHandler());
};
const errorHandler = createHostModule({
    withErrorHandler: getFromHostErrorHandlerOrDefault((e) => e.withErrorHandler),
    getResolvedError: getFromHostErrorHandlerOrDefault((e) => e.getResolvedError),
    showError: getFromHostErrorHandlerOrDefault((e) => e.showError),
    reportRetryAttempt: getFromHostErrorHandlerOrDefault((e) => e.reportRetryAttempt),
});
export const withErrorHandler = errorHandler.withErrorHandler;
export const getResolvedError = errorHandler.getResolvedError;
export const showError = errorHandler.showError;
/** @internal */
export const reportRetryAttempt = errorHandler.reportRetryAttempt;
